@@ -29,8 +29,7 @@
 #include <KAction>
 #include <KActionCollection>
 #include <KCmdLineArgs>
-#include <KDebug>
-#include <KStandardDirs>
+#include <QDebug>
 
 // Konsole
 #include "SessionManager.h"
@@ -72,10 +71,8 @@ MainWindow* Application::newMainWindow()
 {
     MainWindow* window = new MainWindow();
 
-    connect(window, SIGNAL(newWindowRequest(Profile::Ptr,QString)),
-            this, SLOT(createWindow(Profile::Ptr,QString)));
-    connect(window, SIGNAL(viewDetached(Session*)),
-            this, SLOT(detachView(Session*)));
+    connect(window, &Konsole::MainWindow::newWindowRequest, this, &Konsole::Application::createWindow);
+    connect(window, &Konsole::MainWindow::viewDetached, this, &Konsole::Application::detachView);
 
     return window;
 }
@@ -184,7 +181,7 @@ void Application::processTabsFromFileArgs(KCmdLineArgs* args,
     const QString tabsFileName(args->getOption("tabs-from-file"));
     QFile tabsFile(tabsFileName);
     if (!tabsFile.open(QFile::ReadOnly)) {
-        kWarning() << "ERROR: Cannot open tabs file "
+        qWarning() << "ERROR: Cannot open tabs file "
                    << tabsFileName.toLocal8Bit().data();
         quit();
     }
@@ -208,13 +205,13 @@ void Application::processTabsFromFileArgs(KCmdLineArgs* args,
             createTabFromArgs(args, window, lineTokens);
             sessions++;
         } else {
-            kWarning() << "Each line should contain at least one of 'command' and 'profile'.";
+            qWarning() << "Each line should contain at least one of 'command' and 'profile'.";
         }
     }
     tabsFile.close();
 
     if (sessions < 1) {
-        kWarning() << "No valid lines found in "
+        qWarning() << "No valid lines found in "
                    << tabsFileName.toLocal8Bit().data();
         quit();
     }
@@ -415,7 +412,7 @@ Profile::Ptr Application::processProfileChangeArgs(KCmdLineArgs* args, Profile::
 
         // Note: KCmdLineArgs::count() return the number of arguments
         // that aren't options.
-        if (args->count() == 0 && KStandardDirs::findExe(commandExec).isEmpty()) {
+        if (args->count() == 0 && QStandardPaths::findExecutable(commandExec).isEmpty()) {
             // Example: konsole -e "man ls"
             ShellCommand shellCommand(args->getOption("e"));
             commandExec = shellCommand.command();
@@ -449,14 +446,15 @@ void Application::startBackgroundMode(MainWindow* window)
         return;
     }
 
-    KAction* action = window->actionCollection()->addAction("toggle-background-window");
+/* This doesn't work ATM - leave in here so I dont' forget about it
+    KActionCollection* collection = window->actionCollection();
+    KAction* action = collection->addAction("toggle-background-window");
     action->setObjectName(QLatin1String("Konsole Background Mode"));
     action->setText(i18n("Toggle Background Window"));
     action->setGlobalShortcut(KShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F12)));
 
-    connect(action, SIGNAL(triggered()),
-            this, SLOT(toggleBackgroundInstance()));
-
+    connect(action, &KAction::triggered, this, &Application::toggleBackgroundInstance);
+*/
     _backgroundInstance = window;
 }
 
@@ -475,5 +473,3 @@ void Application::toggleBackgroundInstance()
     }
 }
 
-#include "Application.moc"
-
